==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Widgets/PropertyEditor/ts/PropertyEditor_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>AddCustomPropertyDialog</name>
    <message>
        <location filename="../AddCustomPropertyDialog.ui" line="+14"/>
        <source>Add Custom Property</source>
        <translation>Benutzerdefinierte Eigenschaft hinzufügen</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Name:</source>
        <translation>Name:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Value:</source>
        <translation>Wert:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="obsolete">Typ:</translation>
    </message>
</context>
<context>
    <name>PropertyEditor</name>
    <message>
        <location filename="../PropertyEditor.js" line="+190"/>
        <source>*VARIES*</source>
        <translation>*VARIIERT*</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>:</source>
        <translation>:</translation>
    </message>
    <message>
        <location line="+137"/>
        <source>No Selection</source>
        <translation>Keine Selektion</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Geometry</source>
        <translation>Geometrie</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Dependent Entities</source>
        <translation>Abhängige Objekte</translation>
    </message>
    <message>
        <location line="+152"/>
        <source>Index</source>
        <translation>Index</translation>
    </message>
    <message>
        <location line="+59"/>
        <source>Remove this property from selected objects</source>
        <translation>Eigenschaft von ausgewählten Objekten entfernen</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <source>Add Custom Property</source>
        <translation type="obsolete">Benutzerdefiniertes Property hinzufügen</translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="obsolete">Links</translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="obsolete">Zentrum</translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="obsolete">Rechts</translation>
    </message>
    <message>
        <source>Aligned</source>
        <translation type="obsolete">Ausgerichtet</translation>
    </message>
    <message>
        <source>Fit</source>
        <translation type="obsolete">Anpassen</translation>
    </message>
    <message>
        <source>Top</source>
        <translation type="obsolete">Oben</translation>
    </message>
    <message>
        <source>Middle</source>
        <translation type="obsolete">Mittelpunkt</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Add custom property to selected objects</source>
        <translation>Benutzerdefinierte Eigenschaft an ausgewählte Objekte hinzufügen</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation type="obsolete">Unten</translation>
    </message>
    <message>
        <source>Base</source>
        <translation type="obsolete">Basis</translation>
    </message>
    <message>
        <location line="+136"/>
        <source>Auto</source>
        <translation>auto</translation>
    </message>
    <message>
        <location line="+119"/>
        <source>Use auto measurement</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No</source>
        <translation>Nein</translation>
    </message>
    <message>
        <source>-</source>
        <translation type="obsolete">-</translation>
    </message>
    <message>
        <location line="+317"/>
        <location line="+12"/>
        <source>Property Editor</source>
        <translation>Eigenschaften Editor</translation>
    </message>
    <message>
        <location filename="../PropertyEditor.ui" line="+40"/>
        <source>Selection:</source>
        <translation>Auswahl:</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <location line="+183"/>
        <source>Handle:</source>
        <translation>Handle:</translation>
    </message>
    <message>
        <source>Layer:</source>
        <translation type="obsolete">Layer:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation type="obsolete">Farbe:</translation>
    </message>
    <message>
        <source>Lineweight:</source>
        <translation type="obsolete">Linienbreite:</translation>
    </message>
    <message>
        <source>Linetype:</source>
        <translation type="obsolete">Linientyp:</translation>
    </message>
    <message>
        <source>Draw Order:</source>
        <translation type="obsolete">Reihenfolge:</translation>
    </message>
    <message>
        <location line="-20"/>
        <source>Move Selection to a New Layer</source>
        <translation>Auswahl auf neuen Layer verschieben</translation>
    </message>
    <message>
        <location filename="../PropertyEditor.js" line="-863"/>
        <source>Custom</source>
        <translation>Benutzerdefiniert</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Widgets/PropertyEditor/ts/PropertyEditor_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>AddCustomPropertyDialog</name>
    <message>
        <location filename="../AddCustomPropertyDialog.ui" line="+14"/>
        <source>Add Custom Property</source>
        <translation>Benutzerdefinierte Eigenschaft hinzufügen</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Name:</source>
        <translation>Name:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Value:</source>
        <translation>Wert:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="obsolete">Typ:</translation>
    </message>
</context>
<context>
    <name>PropertyEditor</name>
    <message>
        <location filename="../PropertyEditor.js" line="+1318"/>
        <source>*VARIES*</source>
        <translation>*VARIIERT*</translation>
    </message>
    <message>
        <location line="-1130"/>
        <source>:</source>
        <translation>:</translation>
    </message>
    <message>
        <location line="+150"/>
        <source>No Selection</source>
        <translation>Keine Selektion</translation>
    </message>
    <message>
        <source>Geometry</source>
        <translation type="vanished">Geometrie</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Specific Properties</source>
        <translation>Spezifische Eigenschaften</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Dependent Entities</source>
        <translation>Abhängige Objekte</translation>
    </message>
    <message>
        <location line="+183"/>
        <source>Index</source>
        <translation>Index</translation>
    </message>
    <message>
        <location line="+59"/>
        <source>Remove this property from selected objects</source>
        <translation>Eigenschaft von ausgewählten Objekten entfernen</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <location line="+639"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <source>Add Custom Property</source>
        <translation type="obsolete">Benutzerdefiniertes Property hinzufügen</translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="obsolete">Links</translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="obsolete">Zentrum</translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="obsolete">Rechts</translation>
    </message>
    <message>
        <source>Aligned</source>
        <translation type="obsolete">Ausgerichtet</translation>
    </message>
    <message>
        <source>Fit</source>
        <translation type="obsolete">Anpassen</translation>
    </message>
    <message>
        <source>Top</source>
        <translation type="obsolete">Oben</translation>
    </message>
    <message>
        <source>Middle</source>
        <translation type="obsolete">Mittelpunkt</translation>
    </message>
    <message>
        <location line="-617"/>
        <source>Add custom property to selected objects</source>
        <translation>Benutzerdefinierte Eigenschaft an ausgewählte Objekte hinzufügen</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation type="obsolete">Unten</translation>
    </message>
    <message>
        <source>Base</source>
        <translation type="obsolete">Basis</translation>
    </message>
    <message>
        <location line="+136"/>
        <source>Auto</source>
        <translation>auto</translation>
    </message>
    <message>
        <location line="+121"/>
        <source>Use auto measurement</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No</source>
        <translation>Nein</translation>
    </message>
    <message>
        <source>-</source>
        <translation type="obsolete">-</translation>
    </message>
    <message>
        <location line="+320"/>
        <location line="+57"/>
        <location line="+11"/>
        <source>Property Editor</source>
        <translation>Eigenschaften Editor</translation>
    </message>
    <message>
        <location filename="../PropertyEditor.ui" line="+40"/>
        <source>Selection:</source>
        <translation>Auswahl:</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="vanished">Allgemein</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>General Properties</source>
        <translation>Allgemeine Eigenschaften</translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Handle:</source>
        <translation>Handle:</translation>
    </message>
    <message>
        <location line="+94"/>
        <source>Linetype Scale:</source>
        <translation>Linientypskalierung:</translation>
    </message>
    <message>
        <location line="+49"/>
        <source>Protected:</source>
        <translation>Geschützt:</translation>
    </message>
    <message>
        <source>Layer:</source>
        <translation type="obsolete">Layer:</translation>
    </message>
    <message>
        <location line="-153"/>
        <source>Color:</source>
        <translation>Farbe:</translation>
    </message>
    <message>
        <source>Lineweight:</source>
        <translation type="obsolete">Linienbreite:</translation>
    </message>
    <message>
        <source>Linetype:</source>
        <translation type="obsolete">Linientyp:</translation>
    </message>
    <message>
        <source>Draw Order:</source>
        <translation type="obsolete">Reihenfolge:</translation>
    </message>
    <message>
        <source>Move Selection to a New Layer</source>
        <translation type="vanished">Auswahl auf neuen Layer verschieben</translation>
    </message>
    <message>
        <location filename="../PropertyEditor.js" line="-1000"/>
        <source>Custom</source>
        <translation>Benutzerdefiniert</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Display Z coordinates</source>
        <translation>Z Koordinaten anzeigen</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Display properties of current block and current layer</source>
        <translation>Eigenschaften des aktuellen Blocks und des aktuallen Layers anzeigen</translation>
    </message>
</context>
</TS>
